==> logger_36-2024.20-py3-none-any.whl: logger_36/config/logger.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import logging as lggg

from logger_36.catalog.handler.console import console_handler_t
from logger_36.catalog.handler.console_rich import console_rich_handler_t
from logger_36.catalog.handler.file import file_handler_t
from logger_36.catalog.handler.generic import generic_handler_t
from logger_36.constant.handler import HANDLER_CODES, handler_codes_h
from logger_36.instance.logger import LOGGER
from logger_36.task.format.message import FormattedMessage


def SetLOGLevel(
    level: int,
    /,
    *,
    logger: lggg.Logger | None = None,
    which: handler_codes_h | str = "a",
) -> None:
    """
    which: g=generic, c=console, f=file, a=all, str=name.
    """
    if logger is None:
        logger = LOGGER

    which_is_name = which not in HANDLER_CODES
    found = False
    for handler in logger.handlers:
        if (
            (which == "a")
            or ((which == "g") and isinstance(handler, generic_handler_t))
            or (
                (which == "c")
                and isinstance(handler, (console_handler_t, console_rich_handler_t))
            )
            or ((which == "f") and isinstance(handler, file_handler_t))
            or (which == handler.name)
        ):
            handler.setLevel(level)
            if which_is_name:
                return
            found = True

    if not found:
        raise ValueError(
            FormattedMessage(
                "Handler not found",
                actual=which,
                expected=f"{str(HANDLER_CODES)[1:-1]}, or a handler name",
            )
        )


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""

==> logger_36-2025.4-py3-none-any.whl: logger_36/config/logger.py <==
"""
Copyright CNRS/Inria/UniCA
Contributor(s): Eric Debreuve (eric.debreuve@cnrs.fr) since 2023
SEE COPYRIGHT NOTICE BELOW
"""

import logging as lggg

from logger_36.catalog.handler.console import console_handler_t
from logger_36.catalog.handler.console_rich import console_rich_handler_t
from logger_36.catalog.handler.file import file_handler_t
from logger_36.catalog.handler.generic import generic_handler_t
from logger_36.constant.handler import HANDLER_CODES, handler_codes_h
from logger_36.instance.logger import LOGGER
from logger_36.task.format.message import MessageWithActualExpected


def SetLOGLevel(
    level: int,
    /,
    *,
    logger: lggg.Logger | None = None,
    which: handler_codes_h | str = "a",
) -> None:
    """
    which: g=generic, c=console, f=file, a=all, str=name.
    """
    if logger is None:
        logger = LOGGER

    which_is_name = which not in HANDLER_CODES
    found = False
    for handler in logger.handlers:
        if (
            (which == "a")
            or ((which == "g") and isinstance(handler, generic_handler_t))
            or (
                (which == "c")
                and isinstance(handler, (console_handler_t, console_rich_handler_t))
            )
            or ((which == "f") and isinstance(handler, file_handler_t))
            or (which == handler.name)
        ):
            handler.setLevel(level)
            if which_is_name:
                return
            found = True

    if not found:
        raise ValueError(
            MessageWithActualExpected(
                "Handler not found",
                actual=which,
                expected=f"{str(HANDLER_CODES)[1:-1]}, or a handler name",
            )
        )


"""
COPYRIGHT NOTICE

This software is governed by the CeCILL  license under French law and
abiding by the rules of distribution of free software.  You can  use,
modify and/ or redistribute the software under the terms of the CeCILL
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info".

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability.

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or
data to be ensured and,  more generally, to use and operate it in the
same conditions as regards security.

The fact that you are presently reading this means that you have had
knowledge of the CeCILL license and that you accept its terms.

SEE LICENCE NOTICE: file README-LICENCE-utf8.txt at project source root.

This software is being developed by Eric Debreuve, a CNRS employee and
member of team Morpheme.
Team Morpheme is a joint team between Inria, CNRS, and UniCA.
It is hosted by the Centre Inria d'Université Côte d'Azur, Laboratory
I3S, and Laboratory iBV.

CNRS: https://www.cnrs.fr/index.php/en
Inria: https://www.inria.fr/en/
UniCA: https://univ-cotedazur.eu/
Centre Inria d'Université Côte d'Azur: https://www.inria.fr/en/centre/sophia/
I3S: https://www.i3s.unice.fr/en/
iBV: http://ibv.unice.fr/
Team Morpheme: https://team.inria.fr/morpheme/
"""
